package com.ruoyi.base.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.base.mapper.RobotOpsSysLogMapper;
import com.ruoyi.base.domain.RobotOpsSysLog;
import com.ruoyi.base.service.IRobotOpsSysLogService;

/**
 * 运行日志Service业务层处理
 * 
 * @author ruoyi
 * @date 2026-05-18
 */
@Service
public class RobotOpsSysLogServiceImpl implements IRobotOpsSysLogService 
{
    @Autowired
    private RobotOpsSysLogMapper robotOpsSysLogMapper;

    /**
     * 查询运行日志
     * 
     * @param id 运行日志主键
     * @return 运行日志
     */
    @Override
    public RobotOpsSysLog selectRobotOpsSysLogById(Long id)
    {
        return robotOpsSysLogMapper.selectRobotOpsSysLogById(id);
    }

    /**
     * 查询运行日志列表
     * 
     * @param robotOpsSysLog 运行日志
     * @return 运行日志
     */
    @Override
    public List<RobotOpsSysLog> selectRobotOpsSysLogList(RobotOpsSysLog robotOpsSysLog)
    {
        return robotOpsSysLogMapper.selectRobotOpsSysLogList(robotOpsSysLog);
    }

    /**
     * 新增运行日志
     * 
     * @param robotOpsSysLog 运行日志
     * @return 结果
     */
    @Override
    public int insertRobotOpsSysLog(RobotOpsSysLog robotOpsSysLog)
    {
        robotOpsSysLog.setCreateTime(DateUtils.getNowDate());
        return robotOpsSysLogMapper.insertRobotOpsSysLog(robotOpsSysLog);
    }

    /**
     * 修改运行日志
     * 
     * @param robotOpsSysLog 运行日志
     * @return 结果
     */
    @Override
    public int updateRobotOpsSysLog(RobotOpsSysLog robotOpsSysLog)
    {
        return robotOpsSysLogMapper.updateRobotOpsSysLog(robotOpsSysLog);
    }

    /**
     * 批量删除运行日志
     * 
     * @param ids 需要删除的运行日志主键
     * @return 结果
     */
    @Override
    public int deleteRobotOpsSysLogByIds(Long[] ids)
    {
        return robotOpsSysLogMapper.deleteRobotOpsSysLogByIds(ids);
    }

    /**
     * 删除运行日志信息
     * 
     * @param id 运行日志主键
     * @return 结果
     */
    @Override
    public int deleteRobotOpsSysLogById(Long id)
    {
        return robotOpsSysLogMapper.deleteRobotOpsSysLogById(id);
    }
}
